==> members-facade-2.1.9-20210915.063642-1-sources.jar: com/bizvane/members/facade/service/inner/MemberDesensitizeService.java <==
package com.bizvane.members.facade.service.inner;

import com.bizvane.members.facade.models.IntegralRecordModel;
import com.bizvane.members.facade.models.MbrGroupModel;
import com.bizvane.members.facade.vo.ConsumeRecordVo;
import com.bizvane.members.facade.vo.MemberInfoCardVo;
import com.bizvane.members.facade.vo.MemberInfoVo;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;

/**
 * @author huangxinliu
 * @date: 2021/1/25 14:50
 */
public interface MemberDesensitizeService {

    /**
     * 根据账号配置决定脱敏会员信息
     */
    void encryptByAccountConfig(SysAccountPO sysAccountPO, MemberInfoVo memberInfoVo);
    void encryptByAccountConfig(SysAccountPO sysAccountPO, ResponseData<PageInfo<MemberInfoVo>> res);

    /**
     * 根据账号配置决定脱敏会员消费统计信息
     */
    void encryptConsumeRecordVoByAccountConfig(SysAccountPO sysAccountPO, ConsumeRecordVo consumeRecordVo);

    /**
     * 根据账号配置决定脱敏会员卡信息
     */
    void encryptMemberInfoCardVoByAccountConfig(SysAccountPO sysAccountPO, MemberInfoCardVo memberInfoCardVo);

    /**
     * 根据账号配置决定脱敏会员分组
     */
    void encryptMbrGroupModelByAccountConfig(SysAccountPO sysAccountPO, MbrGroupModel mbrGroupModel);
    void encryptMbrGroupModelResByAccountConfig(SysAccountPO sysAccountPO, ResponseData<PageInfo<MbrGroupModel>> res);

    /**
     * 根据账号配置决定脱敏积分流水
     */
    void encryptIntegralRecordModelPageInfoByAccountConfig(SysAccountPO sysAccountPO, PageInfo<IntegralRecordModel> pageInfo);

    /**
     * 查询账号会员数据脱敏配置-根据sysAccountId
     */
    Boolean getMemberDataDesensitizeByAccountConfig(Long sysAccountId);
    /**
     * 查询账号会员数据脱敏配置
     */
    Boolean getMemberDataDesensitizeByAccountConfig(SysAccountPO sysAccountPO);
    
}

==> members-facade-20250930-20250911.065924-3-sources.jar: com/bizvane/members/facade/service/inner/MemberDesensitizeService.java <==
package com.bizvane.members.facade.service.inner;

import com.bizvane.members.facade.es.pojo.MembersInfoSearchPojo;
import com.bizvane.members.facade.models.IntegralRecordModel;
import com.bizvane.members.facade.models.MbrGroupModel;
import com.bizvane.members.facade.vo.ConsumeRecordVo;
import com.bizvane.members.facade.vo.MemberInfoCardVo;
import com.bizvane.members.facade.vo.MemberInfoVo;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;

/**
 * @author huangxinliu
 * @date: 2021/1/25 14:50
 */
public interface MemberDesensitizeService {

    /**
     * 根据账号配置决定脱敏会员信息
     */
    void encryptByAccountConfig(SysAccountPO sysAccountPO, MemberInfoVo memberInfoVo);
    void encryptByAccountConfig(SysAccountPO sysAccountPO, ResponseData<PageInfo<MemberInfoVo>> res);

    void decryptResultPojo(PageInfo<MembersInfoSearchPojo> res);

    /**
     * 根据账号配置决定脱敏会员消费统计信息
     */
    void encryptConsumeRecordVoByAccountConfig(SysAccountPO sysAccountPO, ConsumeRecordVo consumeRecordVo);

    /**
     * 根据账号配置决定脱敏会员卡信息
     */
    void encryptMemberInfoCardVoByAccountConfig(SysAccountPO sysAccountPO, MemberInfoCardVo memberInfoCardVo);

    /**
     * 根据账号配置决定脱敏会员分组
     */
    void encryptMbrGroupModelByAccountConfig(SysAccountPO sysAccountPO, MbrGroupModel mbrGroupModel);
    void encryptMbrGroupModelResByAccountConfig(SysAccountPO sysAccountPO, ResponseData<PageInfo<MbrGroupModel>> res);

    /**
     * 根据账号配置决定脱敏积分流水
     */
    void encryptIntegralRecordModelPageInfoByAccountConfig(SysAccountPO sysAccountPO, PageInfo<IntegralRecordModel> pageInfo);

    /**
     * 查询账号会员数据脱敏配置-根据sysAccountId
     */
    Boolean getMemberDataDesensitizeByAccountConfig(Long sysAccountId);
    /**
     * 查询账号会员数据脱敏配置
     */
    Boolean getMemberDataDesensitizeByAccountConfig(SysAccountPO sysAccountPO);
    
}
